/**
 * This program has been developed by students from the bachelor Computer Science at
 * Utrecht University within the Software Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

/* istanbul ignore file */
/* The comment above was added so the code coverage wouldn't count this file towards code coverage.
 * We do not test components/renderfunctions/styling files.
 * See testing plan for more details.*/
import React, { useState, useRef, useEffect } from 'react';
import logo_white from './gp-logo-white.svg';
import logo from './gp-logo.svg';
import { useAuthorizationCache, useAuth } from '@graphpolaris/shared/lib/data-access';
import DatabaseSelector from './DatabaseManagement/dbConnectionSelector';
import { DropdownItem, DropdownItemContainer } from '@graphpolaris/shared/lib/components/dropdowns';
import GpLogo from './gp-logo';

export const Navbar = () => {
  const dropdownRef = useRef<HTMLDivElement>(null);
  const auth = useAuth();
  const authCache = useAuthorizationCache();
  const [menuOpen, setMenuOpen] = useState(false);

  const currentLogo = !'dark' ? logo_white : logo; // TODO: support dark mode

  useEffect(() => {
    const handleClickOutside = (event: MouseEvent) => {
      if (dropdownRef.current && !dropdownRef.current.contains(event.target as Node)) {
        setMenuOpen(false);
      }
    };
    if (menuOpen) document.addEventListener('mousedown', handleClickOutside);
    return () => {
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, [menuOpen]);

  const buildInfo = import.meta.env.GRAPHPOLARIS_VERSION;

  return (
    <div className="w-full h-auto px-5">
      <div className="navbar flex items-center justify-between w-auto gap-2 xl:gap-10">
        <div>
          <a href="https://graphpolaris.com/" target="_blank" className="w-[10rem] md:w-fit shrink-0 text-dark">
            <GpLogo className="w-48" />
          </a>
          <DatabaseSelector />
        </div>

        <div>
          <div className="w-fit" ref={dropdownRef}>
            <div
              className="relative inline-flex items-center justify-center w-8 h-8 overflow-hidden bg-secondary-500 rounded-full hover:bg-secondary-600 transition-colors duration-150 ease-in-out cursor-pointer"
              onClick={() => setMenuOpen(!menuOpen)}
            >
              <span className="font-medium text-light">{authCache.username?.slice(0, 2).toUpperCase()}</span>
            </div>

            {menuOpen && (
              <DropdownItemContainer className="w-56" align="right-7">
                <div className="p-2 text-sm border-b">
                  <h2 className="font-bold">user: {authCache.username}</h2>
                  <h3 className="text-xs break-words">session: {authCache.sessionID}</h3>
                </div>

                {authCache.authorized ? (
                  <>
                    <DropdownItem
                      value="Share"
                      onClick={() => {
                        auth.newShareRoom();
                      }}
                    />
                    <DropdownItem
                      value="Advanced"
                      submenu={
                        <>
                          <DropdownItem value="TBD" onClick={() => {}} />
                        </>
                      }
                    />
                    <DropdownItem value="Settings" onClick={() => {}} />
                    <DropdownItem value="Log out" onClick={() => {}} />
                  </>
                ) : (
                  <>
                    <DropdownItem value="Login" onClick={() => {}} />
                  </>
                )}

                {authCache?.roomID && (
                  <div className="p-2 border-b">
                    <h3 className="text-xs break-words">Share ID: {authCache.roomID}</h3>
                  </div>
                )}
                <div className="p-2 border-t">
                  <h3 className="text-xs">Version: {buildInfo}</h3>
                </div>
              </DropdownItemContainer>
            )}
          </div>
        </div>
      </div>
    </div>
  );
};
